==> org-lsst-ccs-drivers-usb-3.0.0-sources.jar: org/lsst/ccs/drivers/usb/UsbInterface.java <==
package org.lsst.ccs.drivers.usb;

import java.util.List;
import org.lsst.ccs.drivers.commons.DriverException;

/**
 ******************************************************************************
 **
 **  Operations for a USB interface
 **
 **  @author Owen Saxton
 **
 ******************************************************************************
 */
public class UsbInterface {
    
    private final UsbInterfaceDescriptor desc;
    private final List<UsbInterface> alts;
    private final List<UsbEndpoint> eps;
    private final UsbDevice devc;


   /**
    ***************************************************************************
    **
    **  Constructor.
    **
    ***************************************************************************
    */
    UsbInterface(UsbInterfaceDescriptor desc, List<UsbInterface> alts,
                 List<UsbEndpoint> eps, UsbDevice devc)
    {
        this.desc = desc;
        this.alts = alts;
        this.eps = eps;
        this.devc = devc;
    }


   /**
    ***************************************************************************
    **
    **  Gets the interface descriptor.
    **
    ***************************************************************************
    */
    public UsbInterfaceDescriptor getDescriptor()
    {
        return desc;
    }


   /**
    ***************************************************************************
    **
    **  Gets the interface string.
    **
    ***************************************************************************
    */
    public String getString()
    {
        return devc.getString(desc.iInterface());
    }


   /**
    ***************************************************************************
    **
    **  Gets the number of alternate settings.
    **
    ***************************************************************************
    */
    public int getNumSettings()
    {
        return alts.size();
    }


   /**
    ***************************************************************************
    **
    **  Gets the list of alternate settings.
    **
    ***************************************************************************
    */
    public List<UsbInterface> getSettings()
    {
        return alts;
    }


   /**
    ***************************************************************************
    **
    **  Gets an alternate setting.
    **
    ***************************************************************************
    */
    public UsbInterface getSetting(int altNum)
    {
        for (UsbInterface alt : alts) {
            if (altNum == alt.getDescriptor().bAlternateSetting()) {
                return alt;
            }
        }
        return null;
    }


   /**
    ***************************************************************************
    **
    **  Gets the active setting number.
    **
    ***************************************************************************
    */
    public int getActiveSettingNumber()
    {
        return devc.getAltSetting(desc.bInterfaceNumber());
    }


   /**
    ***************************************************************************
    **
    **  Gets the active setting.
    **
    ***************************************************************************
    */
    public UsbInterface getActiveSetting()
    {
        int altnum = devc.getAltSetting(desc.bInterfaceNumber());
        for (UsbInterface alt : alts) {
            if (alt.desc.bAlternateSetting() == altnum) return alt;
        }
        return null;
    }


   /**
    ***************************************************************************
    **
    **  Gets the list of endpoints.
    **
    ***************************************************************************
    */
    public List<UsbEndpoint> getEndpoints()
    {
        return eps;
    }


   /**
    ***************************************************************************
    **
    **  Gets an endpoint.
    **
    ***************************************************************************
    */
    public UsbEndpoint getEndpoint(int epAddr)
    {
        for (UsbEndpoint ep : eps) {
            if (epAddr == ep.getDescriptor().bEndpointAddress()) {
                return ep;
            }
        }
        return null;
    }

}

==> org-lsst-ccs-drivers-usb-3.1.0-sources.jar: org/lsst/ccs/drivers/usb/UsbInterface.java <==
package org.lsst.ccs.drivers.usb;

import java.util.List;

/**
 ******************************************************************************
 **
 **  Operations for a USB interface
 **
 **  @author Owen Saxton
 **
 ******************************************************************************
 */
public class UsbInterface {
    
    private final UsbInterfaceDescriptor desc;
    private final List<UsbInterface> alts;
    private final List<UsbEndpoint> eps;
    private final UsbDevice devc;


   /**
    ***************************************************************************
    **
    **  Constructor.
    **
    ***************************************************************************
    */
    UsbInterface(UsbInterfaceDescriptor desc, List<UsbInterface> alts,
                 List<UsbEndpoint> eps, UsbDevice devc)
    {
        this.desc = desc;
        this.alts = alts;
        this.eps = eps;
        this.devc = devc;
    }


   /**
    ***************************************************************************
    **
    **  Gets the interface descriptor.
    **
    **  @return  The interface descriptor
    **
    ***************************************************************************
    */
    public UsbInterfaceDescriptor getDescriptor()
    {
        return desc;
    }


   /**
    ***************************************************************************
    **
    **  Gets the interface string.
    **
    **  @return  The interface string
    **
    ***************************************************************************
    */
    public String getString()
    {
        return devc.getString(desc.iInterface());
    }


   /**
    ***************************************************************************
    **
    **  Gets the number of alternate settings.
    **
    **  @return  The number of alternate settings
    **
    ***************************************************************************
    */
    public int getNumSettings()
    {
        return alts.size();
    }


   /**
    ***************************************************************************
    **
    **  Gets the list of alternate settings.
    **
    **  @return  The list of alternate settings
    **
    ***************************************************************************
    */
    public List<UsbInterface> getSettings()
    {
        return alts;
    }


   /**
    ***************************************************************************
    **
    **  Gets an alternate setting.
    **
    **  @param  altNum  The alternate setting number
    **
    **  @return  The alternate setting, or null if the number doesn't exist
    **
    ***************************************************************************
    */
    public UsbInterface getSetting(int altNum)
    {
        for (UsbInterface alt : alts) {
            if (altNum == alt.getDescriptor().bAlternateSetting()) {
                return alt;
            }
        }
        return null;
    }


   /**
    ***************************************************************************
    **
    **  Gets the active setting number.
    **
    **  @return  The active setting number
    **
    ***************************************************************************
    */
    public int getActiveSettingNumber()
    {
        return devc.getAltSetting(desc.bInterfaceNumber());
    }


   /**
    ***************************************************************************
    **
    **  Gets the active setting.
    **
    **  @return  The active setting, or null is none is active
    **
    ***************************************************************************
    */
    public UsbInterface getActiveSetting()
    {
        int altnum = devc.getAltSetting(desc.bInterfaceNumber());
        for (UsbInterface alt : alts) {
            if (alt.desc.bAlternateSetting() == altnum) return alt;
        }
        return null;
    }


   /**
    ***************************************************************************
    **
    **  Gets the list of endpoints.
    **
    **  @return  The list of endpoints
    **
    ***************************************************************************
    */
    public List<UsbEndpoint> getEndpoints()
    {
        return eps;
    }


   /**
    ***************************************************************************
    **
    **  Gets an endpoint.
    **
    **  @param  epAddr  The endpoint address
    **
    **  @return  The endpoint, or null if the endpoint doesn't exist
    **
    ***************************************************************************
    */
    public UsbEndpoint getEndpoint(int epAddr)
    {
        for (UsbEndpoint ep : eps) {
            if (epAddr == ep.getDescriptor().bEndpointAddress()) {
                return ep;
            }
        }
        return null;
    }

}
